var Logger = function(name) {
  this.name = name;
}

Logger.levels = ['DEBUG', 'INFO', 'WARN', 'ERROR', 'FATAL'];

var LogMessage = function(level, message) {
  this.level = level;
  this.message = message;
}

var logFn = function(level) {
  return function(message) {
    this.log(new LogMessage(level, message));
  }
}

var charm = require('charm')(null, process.stdout);

Logger.prototype.log = function(msg) {
  var color = 'white';
  switch(msg.level) {
    case 'info': color = 'green'; break;
    case 'warn': color = 'yellow'; break;
    case 'error': color = 'red'; break;
    case 'fatal': color = 'red'; break;
  }
  charm.foreground(color);
  process.stdout.write(msg.level.toUpperCase());
  process.stdout.write(' : ');
  if(typeof msg.message == 'string') {
    process.stdout.write(msg.message);
  } else {
    process.stdout.write(JSON.stringify(msg.message));
  }
  charm.foreground('white');
  process.stdout.write('\n');
}

Logger.prototype.debug = logFn('debug');
Logger.prototype.info = logFn('info');
Logger.prototype.warn = logFn('warn');
Logger.prototype.error = logFn('error');
Logger.prototype.fatal = logFn('fatal');

module.exports = function(name) {
  return new Logger(name || '');
};
